import { IHOTPOptions, IOTPToken } from '@zodash/hotp';
export interface ITOTP {
    /**
    * Get an OTP Token based HMAC-SHA-1
    *
    * @param secret secret string
    * @param options optional options
    */
    generate(secret: string, options?: IGetOptions): Promise<IOTPToken>;
    /**
     * Verify OTP Token is valid to Secret
     *
     * @param token one-time password
     * @param secret secret string
     * @param options optional options
     */
    verify(token: IOTPToken, secret: string, options?: IVerifyOptions): Promise<boolean>;
    /**
     * Get TOTP URI
     *
     * @param secret secret string
     * @param account account
     * @param issuer issuer or organazation
     */
    getURI(secret: string, account: string, issuer: string): Promise<string>;
    /**
     * Get TTL
     *
     * @param timeStep number, optional
     * @param startedAt milliseconds, optional
     */
    getTTL(timeStep?: number, startedAt?: number): Promise<number>;
    /**
     * Get Time Counter
     * @param timeStep number, optional
     * @param startedAt milliseconds, optional
     */
    getTimeCounter(timeStep?: number, startedAt?: number): Promise<number>;
}
export interface ITOTPOptions extends IHOTPOptions {
}
export interface IGetOptions {
    /**
     * Time step seconds, default: 30
     */
    timeStep?: number;
    /**
     * Started time seconds, default: 0
     */
    startedAt?: number;
    /**
     * One-time password length, default: 6
     */
    length?: number;
}
export declare type IVerifyOptions = IGetOptions;
export declare class TOTP implements ITOTP {
    private readonly options?;
    private hotp;
    static generateSecret(length?: number): any;
    constructor(options?: ITOTPOptions);
    generate(secret: string, options?: IGetOptions): Promise<IOTPToken>;
    verify(token: IOTPToken, secret: string, options?: IVerifyOptions): Promise<boolean>;
    getURI(secret: string, account: string, issuer: string): Promise<string>;
    getTTL(timeStep?: number, startedAt?: number): Promise<number>;
    getTimeCounter(timeStep?: number, startedAt?: number): Promise<number>;
}
export default TOTP;
