"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TOTP = void 0;
const hotp_1 = require("@zodash/hotp");
const utils_1 = require("./utils");
class TOTP {
    constructor(options) {
        this.options = options;
        this.hotp = new hotp_1.default(this.options);
    }
    static generateSecret(length) {
        return hotp_1.default.generateSecret(length);
    }
    async generate(secret, options) {
        const timeStep = options === null || options === void 0 ? void 0 : options.timeStep;
        const startedAt = options === null || options === void 0 ? void 0 : options.startedAt;
        const length = options === null || options === void 0 ? void 0 : options.length;
        const timeCounter = await this.getTimeCounter(timeStep, startedAt);
        return this.hotp.generate(secret, timeCounter, { length });
    }
    async verify(token, secret, options) {
        return token === await this.generate(secret, options);
    }
    async getURI(secret, account, issuer) {
        return `otpauth://totp/${account}?issuer=${issuer}&secret=${secret}`;
    }
    async getTTL(timeStep, startedAt) {
        return utils_1.getTTL(timeStep, startedAt);
    }
    async getTimeCounter(timeStep, startedAt) {
        return utils_1.getTimeCounter(timeStep, startedAt);
    }
}
exports.TOTP = TOTP;
exports.default = TOTP;
